@@ -147,22 +147,23 @@ public class ResourcesListViewPanel extends FramedPanel {
 		}
 	}
 
-	enum ResourcesSortInfo {
+	public enum ResourcesSortInfo {
 		Name("Name"), CreationDate("Creation Date");
-
+		
+		private static ResourcesMessages msgs=GWT.create(ResourcesMessages.class);
 		private String id;
-
-		private static List<String> resourcesSortInfoStringList;
+		
+		private static List<String> resourcesSortInfoI18NList;
 
 		static {
-			resourcesSortInfoStringList = new ArrayList<String>();
+			resourcesSortInfoI18NList = new ArrayList<String>();
 			for (ResourcesSortInfo r : values()) {
-				resourcesSortInfoStringList.add(r.getId());
+				resourcesSortInfoI18NList.add(msgs.resourceSortInfo(r));
 			}
 		}
 
 		private ResourcesSortInfo(String id) {
-			this.id = id;
+			this.id = id;	
 		}
 
 		public String getId() {
@@ -172,17 +173,22 @@ public class ResourcesListViewPanel extends FramedPanel {
 		public String toString() {
 			return id;
 		}
-
+		
+		public String getIdI18N(){
+			return msgs.resourceSortInfo(this);
+		}
+		
+		
 		public static List<ResourcesSortInfo> asList() {
 			List<ResourcesSortInfo> list = Arrays.asList(values());
 			return list;
 		}
 
-		public static List<String> asStringList() {
-			return resourcesSortInfoStringList;
+		public static List<String> asI18NList() {
+			return resourcesSortInfoI18NList;
 
 		}
-
+		
 	}
 
 	private ResourcesListViewDetailPanel details;
@@ -268,10 +274,10 @@ public class ResourcesListViewPanel extends FramedPanel {
 							ResourceTDDescriptor o2) {
 
 						String v = comboSort.getCurrentValue();
-						if (v.equals("Name")) {
+						if (v.equals(ResourcesSortInfo.Name.getIdI18N())) {
 							return o1.getName().compareToIgnoreCase(
 									o2.getName());
-						} else if (v.equals("Creation Date")) {
+						} else if (v.equals(ResourcesSortInfo.CreationDate.getIdI18N())) {
 							return o1.getCreationDate().compareTo(
 									o2.getCreationDate());
 
@@ -320,8 +326,8 @@ public class ResourcesListViewPanel extends FramedPanel {
 		comboSort.setEditable(false);
 		comboSort.setForceSelection(true);
 		comboSort.setWidth(120);
-		comboSort.add(ResourcesSortInfo.asStringList());
-		comboSort.setValue(ResourcesSortInfo.CreationDate.getId());
+		comboSort.add(ResourcesSortInfo.asI18NList());
+		comboSort.setValue(ResourcesSortInfo.CreationDate.getIdI18N());
 		comboSort.addSelectionHandler(new SelectionHandler<String>() {
 
 			@Override
